Loading...
osfmk/ppc/aligned_data.s xnu-344.21.74 xnu-792
--- xnu/xnu-344.21.74/osfmk/ppc/aligned_data.s
+++ xnu/xnu-792/osfmk/ppc/aligned_data.s
@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -46,27 +43,25 @@
  
 		
 #include <debug.h>
-#include <cpus.h>
 #include <ppc/asm.h>
 #include <ppc/proc_reg.h>
 #include <ppc/spec_reg.h>
 #include <mach/ppc/vm_param.h>
 #include <assym.s>
 
-;
-;		NOTE: We need this only if PREEMPTSTACK is set to non-zero in hw_lock.
-;		Make sure they are set to the same thing
-;
-#define PREEMPTSTACK 0
-
 			.data
 
 /*		4096-byte aligned areas */
 
-		.globl	EXT(per_proc_info)
+		.globl	EXT(PerProcTable)
 		.align	12
-EXT(per_proc_info):									; Per processor data area
-		.space	(ppSize*NCPUS),0				; (filled with 0s)
+EXT(PerProcTable):									; Per processor table
+		.space	(ppeSize*MAX_CPUS),0				; (filled with 0s)
+
+		.globl	EXT(BootProcInfo)
+		.align	12
+EXT(BootProcInfo):									; Per processor data area
+		.space	ppSize,0							; (filled with 0s)
 
 /*		512-byte aligned areas */
 
@@ -88,19 +83,6 @@
 debstash:
 		.set	.,.+256
 
-#if PREEMPTSTACK
-
-;
-;		NOTE: We need this only if PREEMPTSTACK is set to non-zero in hw_lock.
-;
-
-		.globl	EXT(DBGpreempt)						; preemption debug stack
-		.align	8
-EXT(DBGpreempt):
-		.set	.,.+(NCPUS*PREEMPTSTACK*16)
-#endif
-
-
 /*		128-byte aligned areas */
 
 		.globl	EXT(mapCtl)
@@ -119,18 +101,6 @@
 EXT(free_mappings):
 		.long	0
 
-		.globl	EXT(syncClkSpot)
-		.align	7
-EXT(syncClkSpot):
-		.long	0
-		.long	0
-		.long	0
-		.long	0
-		.long	0
-		.long	0
-		.long	0
-		.long	0
-	
 		.globl	EXT(NMIss)
 		.align	7
 EXT(NMIss):
@@ -196,42 +166,33 @@
 		.globl  EXT(dbspecrs)
 		.align	3
 EXT(dbspecrs):
-		.set	.,.+(80*4)
+		.set	.,.+(336*4)
 
 /*
  *		Interrupt and debug stacks go here
  */
- 	
+
+		.section __HIB, __data
+
 		.align  PPC_PGSHIFT
-     	.globl  EXT(FixedStackStart)
-EXT(FixedStackStart):
      
 	 	.globl  EXT(intstack)
 EXT(intstack):
-		.set	.,.+INTSTACK_SIZE*NCPUS
-	
+
+		.set	.,.+INTSTACK_SIZE
+
+
+                /* back to the regular __DATA section. */
+
+		.section __DATA, __data
+		.align  PPC_PGSHIFT
+
 /* Debugger stack - used by the debugger if present */
-/* NOTE!!! Keep the debugger stack right after the interrupt stack */
 
     	.globl  EXT(debstack)
 EXT(debstack):
-		.set	., .+KERNEL_STACK_SIZE*NCPUS
-     
-		 .globl  EXT(FixedStackEnd)
-EXT(FixedStackEnd):
+		.set	., .+KERNEL_STACK_SIZE
 
-		.align	ALIGN
-   		.globl  EXT(intstack_top_ss)
-EXT(intstack_top_ss):
-		.long	EXT(intstack)+INTSTACK_SIZE-FM_SIZE			/* intstack_top_ss points to the top of interrupt stack */
+		.section __DATA, __data
 
-		.align	ALIGN
-   	 	.globl  EXT(debstack_top_ss)	
-EXT(debstack_top_ss):
 
-		.long	EXT(debstack)+KERNEL_STACK_SIZE-FM_SIZE		/* debstack_top_ss points to the top of debug stack */
-
-    	.globl  EXT(debstackptr)
-EXT(debstackptr):	
-		.long	EXT(debstack)+KERNEL_STACK_SIZE-FM_SIZE
-
@@ -196,42 +166,33 @@
 
 /*
- *		Interrupt and debug stacks go here
+ *		Boot processor Interrupt and debug stacks go here.
  */